fisx: Member List

fisx

fisx::Beam Member List

This is the complete list of members for fisx::Beam, including all inherited members.

Beam() (defined in fisx::Beam) | fisx::Beam |
getBeam() | fisx::Beam |
getBeamAsDoubleVectors() const | fisx::Beam |
operator<< (defined in fisx::Beam) | fisx::Beam | friend
setBeam(const std::vector< double > &energy, const std::vector< double > &weight=std::vector< double >(), const std::vector< int > &characteristic=std::vector< int >(), const std::vector< double > &divergency=std::vector< double >()) | fisx::Beam |
setBeam(const int &nValues, const double *energy, const double *weight=NULL, const int *characteristic=NULL, const double *divergency=NULL) | fisx::Beam |
setBeam(const int &nValues, const double *energy, const double *weight=NULL, const double *characteristic=NULL, const double *divergency=NULL) (defined in fisx::Beam) | fisx::Beam |
setBeam(const double &energy, const double divergency=0.0) (defined in fisx::Beam) | fisx::Beam |